@@ -98,7 +98,7 @@ decimal_pad <- function(col, pad_chars, type) {
 # return data frame mapping real cell positions to cells displayed
 display_cells <- function(ht, all = TRUE, new_rowspan = rowspan(ht), new_colspan = colspan(ht)) {
   dcells <- data.frame(row = rep(1:nrow(ht), ncol(ht)), col = rep(1:ncol(ht), each = nrow(ht)),
-    rowspan = as.vector(new_rowspan), colspan = as.vector(new_colspan))
+        rowspan = as.vector(new_rowspan), colspan = as.vector(new_colspan))
   dcells$display_row <- dcells$row
   dcells$display_col <- dcells$col
   dcells$shadowed <- FALSE
@@ -205,6 +205,64 @@ guess_knitr_output_format <- function() {
   of
 }
 
+#' Insert a row or column
+#'
+#' These convenience functions wrap \code{cbind} or \code{rbind} for huxtables to insert
+#' a single row.
+#' @param ht A huxtable.
+#' @param ... Cell contents.
+#' @param after Insert the row/column after this position. 0 (the default) inserts as the first row/column.
+#' @param copy_cell_props Copy cell properties from the previous row or column (if after > 0). See \code{\link{cbind.huxtable}}.
+#'
+#' @return The modified huxtable
+#' @export
+#'
+#' @examples
+#' ht <- hux(1:5, 1:5, 1:5)
+#' ht <- insert_row(ht, 2.5, 2.5, 2.5, after = 2)
+#' ht
+#' ht <- insert_column(ht, 1, 2, 2.5, 3, 4, 5, after = 3)
+#' ht
+insert_column <- function (ht, ..., after = 0, copy_cell_props = TRUE) {
+  stopifnot(is.numeric(after))
+  stopifnot(after <= ncol(ht) && after >= 0)
+  ht1 <- NULL
+  ht2 <- NULL
+  if (after > 0) {
+    ht1 <- ht[, seq(1, after, 1)]
+  }
+  if (after < ncol(ht)) {
+    ht2 <- ht[, seq(after + 1, ncol(ht), 1)]
+  }
+  to_insert <- c(...)
+  res <- if (! is.null(ht1)) cbind(ht1, to_insert, copy_cell_props = copy_cell_props) else to_insert
+  res <- if (! is.null(ht2)) cbind(res, ht2) else res
+
+  res
+}
+
+
+#' @rdname insert_column
+#'
+#' @export
+insert_row <- function (ht, ..., after = 0, copy_cell_props = TRUE) {
+  stopifnot(is.numeric(after))
+  stopifnot(after <= nrow(ht) && after >= 0)
+  ht1 <- NULL
+  ht2 <- NULL
+  if (after > 0) {
+    ht1 <- ht[seq(1, after, 1), ]
+  }
+  if (after < nrow(ht)) {
+    ht2 <- ht[seq(after + 1, nrow(ht), 1), ]
+  }
+  to_insert <- c(...)
+  res <- if (! is.null(ht1)) rbind(ht1, to_insert, copy_cell_props = copy_cell_props) else to_insert
+  res <- if (! is.null(ht2)) rbind(res, ht2) else res
+
+  res
+}
+
 #' Add a row with a footnote
 #'
 #' This adds a single row at the bottom. The first cell contains the footnote; it spans
