@@ -69,6 +69,20 @@ test_that('huxreg number_format works correctly', {
   expect_match(to_screen(hr2), paste0('\\D', sprintf('%5.3f', coef(lm1)[2]),'\\D'))
 })
 
+
+test_that('huxreg borders argument works', {
+  set.seed(27101975)
+  dfr <- data.frame(y = rnorm(100), a = rnorm(100), b = rnorm(100), d = rnorm(100))
+  dfr$y <- dfr$y + dfr$a
+  lm1 <- lm(y ~ a, dfr)
+  lm2 <- lm(y ~ b, dfr)
+  hr <- huxreg(lm1, lm2)
+  expect_equivalent(bottom_border(hr)[, 2], c(1, rep(0, 5), 1, rep(0, nrow(hr) - 9), 1, 0))
+  hr2 <- huxreg(lm1, lm2, borders = FALSE)
+  expect_equivalent(bottom_border(hr2)[, 2], rep(0, nrow(hr2)))
+})
+
+
 test_that('huxreg stars printed correctly', {
   set.seed(27101975)
   dfr <- data.frame(y = rnorm(20), a = rnorm(20))
